@@ -26,4 +26,16 @@ def get_video_height(file_path):
     if r.returncode != 0:
         mlog.error(r)
         return
-    return int(r.stdout)
\ No newline at end of file
+    return int(r.stdout)
+
+def get_video_duration(file_path):
+    """
+    计算视频时长
+    ffprobe <input> -select_streams v -show_entries stream=duration -of default=nk=1:nw=1 -v quiet
+    """
+    args = ["ffprobe", "-i", file_path, "-select_streams", "v", "-show_entries", "stream=duration", "-of", "default=nk=1:nw=1", "-v", "quiet"]
+    r = subprocess.run(args=args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, encoding="utf-8")
+    if r.returncode != 0:
+        mlog.error(r)
+        return
+    return float(r.stdout)
\ No newline at end of file
